summaryrefslogtreecommitdiff
path: root/expt_0503.cu
diff options
context:
space:
mode:
Diffstat (limited to 'expt_0503.cu')
-rw-r--r--expt_0503.cu12
1 files changed, 6 insertions, 6 deletions
diff --git a/expt_0503.cu b/expt_0503.cu
index 0ada96c..c738e43 100644
--- a/expt_0503.cu
+++ b/expt_0503.cu
@@ -59,10 +59,10 @@ __global__ void kernel(unsigned long step, const double slice_size,
auto tid = step * (blockIdx.x * blockDim.x + threadIdx.x) + i;
// printf("%d\n", tid);
- auto index = (int)(custom_sort.sample_cdf_custom_version(
- cudaSampleItem, cudaPopulationItem[tid]) /
- slice_size) -
- 1;
+ auto index =
+ (int)(custom_sort.cdf(cudaSampleItem, cudaPopulationItem[tid]) /
+ slice_size) -
+ 1;
cdf_result[index] = true;
}
}
@@ -72,8 +72,8 @@ __global__ void kernel2(unsigned long step, const double slice_size) {
for (int i = 0; i < step; i++) {
auto tid = step * (blockIdx.x * blockDim.x + threadIdx.x) + i;
auto index =
- (int)(FactorySort::sample_cdf(cudaNormalSampleItem, cuda_sample_length,
- cudaPopulationItem[tid]) /
+ (int)(FactorySort::cdf(cudaNormalSampleItem, cuda_sample_length,
+ cudaPopulationItem[tid]) /
slice_size) -
1;
cdf_normal_result[index] = true;